@@ -63,7 +63,18 @@ class Substrate():
 				)
 
 		if 'docker' in config:
-			print(subprocess.check_output('docker info', shell=True).decode('utf-8'))
+			try:
+				subprocess.check_call(
+					'docker info',
+					shell=True,
+					stdout=subprocess.DEVNULL,
+					stderr=subprocess.DEVNULL
+				)
+			except subprocess.CalledProcessError as exc:
+				raise Exception(
+					"Docker doesn't appear to be running. Please check that it's installed "
+					"and the daemon is running."
+				) from exc
 
 	def _get_data(self, config):
 		source_paths = config['data']['source']
