@@ -125,10 +125,8 @@ class DockerSwarm():
 					self.log('✓\n')
 
 		self.log('Removing the swarm service…')
-		map(
-			lambda obj: obj.remove(),
-			self.docker.services.list(name=self.tool.name) + self.docker.networks.list(name=f'substrate-{self.tool.name}-net')  # noqa: E501
-		)
+		for obj in self.docker.services.list(filters={'name': self.tool.name}) + self.docker.networks.list(names=[f'substrate-{self.tool.name}-net']):  # noqa: E501
+			obj.remove()
 		self.log('✓\n')
 
 	def log(self, message):
