@@ -20,7 +20,7 @@ class HelloWorld(Tool):
 			'--publish 80:5000/tcp '
 			f'--replicas {self.config.get("aws", {}).get("replicas", 1)} '
 			'--mount type=bind,src=/mnt/efs/data,dst=/data '
-			'evilkermit/substrate-hello-world:latest '
+			'seelab/substrate-hello-world:latest '
 			'python3 -m http.server 5000'
 		)
 
@@ -31,7 +31,7 @@ class HelloWorld(Tool):
 
 		self.port = self.config['docker'].get('port', self.port)
 		docker.services.create(
-			'evilkermit/substrate-hello-world:latest',
+			'seelab/substrate-hello-world:latest',
 			'python3',
 			args=['-m', 'http.server', '8000'],
 			endpoint_spec=EndpointSpec(ports={self.port: (8000, 'tcp')}),
