@@ -20,7 +20,7 @@ class OSPRayStudio(Tool):
 			'--publish 80:5000/tcp '
 			f'--replicas {self.config.get("aws", {}).get("replicas", 1)} '
 			'--mount type=bind,src=/mnt/efs/data,dst=/data '
-			'evilkermit/substrate_ospray_studio:latest '
+			'seelab/substrate-ospray-studio:latest '
 			'flask run --host=0.0.0.0'
 		)
 
@@ -31,7 +31,7 @@ class OSPRayStudio(Tool):
 
 		self.port = self.config['docker'].get('port', self.port)
 		docker.services.create(
-			'evilkermit/substrate_ospray_studio:latest',
+			'seelab/substrate-ospray-studio:latest',
 			'flask',
 			args=['run', '--host=0.0.0.0'],
 			endpoint_spec=EndpointSpec(ports={self.port: (5000, 'tcp')}),
